@@ -169,7 +169,7 @@ class Window(QMainWindow, Ui_Window):
         QShortcut(QKeySequence(self.tr('F11')),
             self, self.information.setFocus)
         QShortcut(QKeySequence(self.tr('F12')),
-            self, self.searchBox.setFocus)
+            self, self.activateSearchBox)
         self.fileOffline.triggered.connect(self.handleWorkOffline)
         self.fileRefresh.triggered.connect(self.handleRefresh)
         self.fileCancel.triggered.connect(self.handleCancelTask)
@@ -266,7 +266,7 @@ class Window(QMainWindow, Ui_Window):
         self.setActive(True, Callback.BackendInitialize)
         backend.initialize()
         self.updateFilters()
-        self.searchBox.setFocus()
+        self.activateSearchBox(True)
 
     def eventFilter(self, widget, event):
         if event.type() == QEvent.StatusTip and not len(event.tip()):
@@ -632,6 +632,12 @@ class Window(QMainWindow, Ui_Window):
         self.searchFiles.setVisible(self.keyFiles.isChecked())
         self.handleSearchChanged()
 
+    def activateSearchBox(self, clear=False):
+        if clear:
+            self.searchBox.clearEditText()
+        self.searchBox.setFocus()
+        self.searchBox.lineEdit().selectAll()
+
     def handleSearchChanged(self, text=None):
         if text is None:
             text = self.searchBox.currentText()
